@@ -33,6 +33,13 @@ class OwncloudControl:
         return "{0}://{1}:{2}/{3}"\
             .format(info.service.protocol, info.external_host, info.external_port, info.service.url)
 
+    def verify(self, host):
+        owncloud_url = 'http://{}:{}/{}'.format(host, self.config.port_http, self.config.url)
+        if not setup.is_finished(owncloud_url):
+            raise Exception("not finished yet")
+        else:
+            return "finished"
+
 
 def get_control(insider, config_path=default_config_path):
     config_filename = os.path.join(config_path, 'owncloud-ctl.cfg')
